const core = require('@actions/core');
const github = require('@actions/github');
const axios = require('axios').default;
const wait = require('./wait');

// most @actions toolkit packages have async methods
async function run() {
  try {
    const ms = parseInt(core.getInput('delay-fetch-ms'));
    core.info(`Waiting ${ms} milliseconds to hit Vercel's API`);
    core.info('(this isn\'t necessary but it soothes a primate impulse in my brain to know that the deploy WILL DEFINITELY have started)')
    await wait(ms);

    const octokit = github.getOctokit(process.env.GITHUB_TOKEN);

    let deployCommit = '';
    if (github.context.eventName === 'push') { // this is good. this works fine.
      deployCommit = github.context.sha;
    } else if (github.context.eventName === 'pull_request') {
      const currentPR = await octokit.rest.pulls.get({
        owner: github.context.payload.repository.owner.login, // 'bramarcade', pretty confident this is good
        repo: github.context.payload.repository.name, // 'bram-arcade' // ppretty confident in this one too
        pull_number: github.context.payload.number, // 1, 2, 3...
      });
      if (currentPR.status !== 200) {
        throw 'Could not get information about the current pull request';
      }
      deployCommit = currentPR.data.head.sha;
    } else {
      throw 'Action was not run on a push or a pull request. Could not find deployCommit.';
    }

    const res = await axios.get('https://api.vercel.com/v6/deployments', {
      headers: {
        Accept: 'application/json',
        Authorization: `Bearer ${process.env.VERCEL_TOKEN}`,
      },
      params: {
        teamId: process.env.VERCEL_TEAM_ID,
      }
    });
    const deploy = res.data.deployments.find((deploy) => deploy.meta.githubCommitSha === deployCommit);
    core.setOutput('deploymentUrl', deploy.url);
  } catch (error) {
    core.setFailed(error.message);
  }
}

run();
